{% load i18n %}
{% load currency_filters %}

{% if basket.is_empty %}
    {% trans "Your basket is now empty" %}
{% else %}
    {% if basket.is_tax_known %}
        {% blocktrans with total=basket.total_incl_tax|currency:basket.currency %}
        Your basket total is now <strong>{{ total }}</strong>
        {% endblocktrans %}
    {% else %}
        {% blocktrans with total=basket.total_excl_tax|currency:basket.currency %}
        Your basket total is now <strong>{{ total }}</strong>
        {% endblocktrans %}
    {% endif %}
{% endif %}

{% if include_buttons %}
    <br>
    <a href="{% url 'basket:summary' %}" class="btn btn-info">{% trans "View basket" %}</a>
    <a href="{% url 'checkout:index' %}" class="btn btn-info">{% trans "Checkout now" %}</a>
{% endif %}
